@@ -797,7 +797,7 @@ def search_maxima(filename: Path, domain_valid: np.ndarray, levels: int, output:
         [1, 1, 1],
         [1, 1, 1]
     ])
-    nodata_mask = ~binary_erosion(domain_valid, footprint=kernel)
+    nodata_mask = ~binary_erosion(domain_valid, kernel)
 
     with rasterio.open(filename) as src:
         profile = src.profile.copy()
@@ -842,7 +842,7 @@ def search_maxima(filename: Path, domain_valid: np.ndarray, levels: int, output:
     return out_class, out_class_phi
 
 
-def generate_composites(files_10m: List[Path], files_20m: List[Path]) -> Iterable[Path]:
+def generate_composites(files_10m: List[Path], files_20m: List[Path], output: Path) -> Iterable[Path]:
     """
     Combine all classification results into several composites
 
@@ -851,6 +851,9 @@ def generate_composites(files_10m: List[Path], files_20m: List[Path]) -> Iterabl
     :param files_20m: List[Path]
         the list of classification results computed at 20 meter pixel resolution
 
+    :param output: Path
+        the complete path where to write results
+
     :return: Iterable[Path]
         the complete path to all composite results saved on disk
     """
@@ -859,10 +862,11 @@ def generate_composites(files_10m: List[Path], files_20m: List[Path]) -> Iterabl
     bounds = common_extent_mollweide(filenames=files_20m)
 
     logs('Generate composite 20m')
-    composite_20m, composite_20m_phi = generate_composite(
+    composite_20m, composite_20m_phi, composite_20m_count = generate_composite(
         tiffiles=files_20m,
         pixres=20,
         bounds=bounds,
+        output=output,
     )
 
     logs('Upsample data 20m to 10m')
@@ -882,10 +886,11 @@ def generate_composites(files_10m: List[Path], files_20m: List[Path]) -> Iterabl
         bounds_20m = src.bounds
 
     logs('Generate composite 10m')
-    composite_10m, composite_10m_phi = generate_composite(
+    composite_10m, composite_10m_phi, composite_10m_count = generate_composite(
         tiffiles=files_10m,
         pixres=10,
         bounds=bounds_20m,
+        output=output,
     )
 
     logs('Merge in composite ALL')
@@ -896,8 +901,8 @@ def generate_composites(files_10m: List[Path], files_20m: List[Path]) -> Iterabl
         comp20m_phi=composite_20m_to_10m_phi,
     )
 
-    return (composite_20m, composite_20m_phi,
-            composite_10m, composite_10m_phi,
+    return (composite_20m, composite_20m_phi, composite_20m_count,
+            composite_10m, composite_10m_phi, composite_10m_count,
             composite_all, composite_all_phi)
 
 
@@ -939,7 +944,7 @@ def common_extent_mollweide(filenames: List[Path]) -> BoundingBox:
     return envelope
 
 
-def generate_composite(tiffiles: List[Path], pixres: int, bounds: BoundingBox) -> (Path, Path):
+def generate_composite(tiffiles: List[Path], pixres: int, bounds: BoundingBox, output: Path) -> (Path, Path):
     """
 
     :param tiffiles: List[Path]
@@ -949,6 +954,9 @@ def generate_composite(tiffiles: List[Path], pixres: int, bounds: BoundingBox) -
     :param bounds: BoundingBox
         the target spatial extent used to clip
 
+    :param output: Path
+        the complete path where to write results
+
     :return: (Path, Path)
          the complete path to the composites of the classification file and the phi value file
     """
@@ -971,6 +979,7 @@ def generate_composite(tiffiles: List[Path], pixres: int, bounds: BoundingBox) -
     # init data
     data = np.zeros(shape=(height, width), dtype=np.uint8)
     data_phi = np.zeros(shape=(height, width), dtype=np.uint8)
+    data_count = np.zeros(shape=(height, width), dtype=np.uint16)
 
     # filter class and phi files
     files_phi = [f for f in tiffiles if '_phi' in str(f)]
@@ -994,6 +1003,9 @@ def generate_composite(tiffiles: List[Path], pixres: int, bounds: BoundingBox) -
                     next_data = vrt.read(1)
                     data[better_phi_domain] = next_data[better_phi_domain]
 
+            # count amount of data used for each pixel
+            data_count += better_phi_domain
+
         # Write output file
         profile = DefaultGTiffProfile(
             count=1,
@@ -1004,16 +1016,21 @@ def generate_composite(tiffiles: List[Path], pixres: int, bounds: BoundingBox) -
         )
 
         # write data
-        composite_data = tiffiles[0].parent / f'composite_S2_CLASS_{pixres}m.tif'
+        composite_data = output / f'composite_S2_CLASS_{pixres}m.tif'
         with rasterio.open(composite_data, 'w', **profile) as dst:
             dst.write(data, 1)
 
         # write phi
-        composite_phi = tiffiles[0].parent / f'composite_S2_CLASS_{pixres}m_phi.tif'
+        composite_phi = output / f'composite_S2_CLASS_{pixres}m_phi.tif'
         with rasterio.open(composite_phi, 'w', **profile) as dst:
             dst.write(data_phi, 1)
 
-    return composite_data, composite_phi
+        # write data count
+        composite_count = output / f'composite_S2_CLASS_{pixres}m_stack_count.tif'
+        with rasterio.open(composite_count, 'w', **profile) as dst:
+            dst.write(data_count, 1)
+
+    return composite_data, composite_phi, composite_count
 
 
 def upsampling_20m_to_10m(filename: Path, resampling: str) -> Path:
